.. -*- mode: ReST -*-

.. _conventions:

===========
Conventions
===========

.. contents:: Contents
   :local:

Package-wide conventions I prefer.

Naming
======

#. Mixins     {}_m.
#. Protocols  {}_p.
#. Interfaces {}_i.
#. Structs    {}_s.
#. Specs      {}_c.
#. Enums      {}_e.
#. Flags      {}_f.
#. Hooks      {}_h.
#. Loggers    {}_l.
#. Kw Conflicts  _{}.
   
